vexalarm.options.profiles.current = ""
vexalarm.options.profiles.name = ""

vexalarm.options.profiles.statusMsg = {
	["save"] = " ",
	["rename"] = " ",
	["load"] = " ",
	["delete"] = " "}

function vexalarm.options.profiles.feedback(category, text, isError)
	for key in pairs(vexalarm.options.profiles.statusMsg) do
		vexalarm.options.profiles.statusMsg[key] = " "
	end
	if isError then
		text = "|CFFC41F3B"..text.."|r"
	else
		text = "|CFF00FF00"..text.."|r"
	end
	
	if vexalarm.options.profiles.statusMsg[category] ~= nil then
		vexalarm.options.profiles.statusMsg[category] = text
	end
end

function vexalarm.options.profiles.save()
	local key = vexalarm.options.profiles.name
	if vexalarm.options.general.checkName(key) then
		vexalarm.options.profiles.createNewProfile(key)
		vexalarm.options.profiles.name = ""
		
		vexalarm.options.profiles.feedback("save", "Profile saved successfully", false)
	else
		vexalarm.options.profiles.feedback("save", "Couldn't save profil. Name is invalid.", true)
	end
end

function vexalarm.options.profiles.createNewProfile(name)
	if name == nil then
		name = GetRealmName().."-"..select(1, UnitName("player"))
	end
	vexalarm_SV_profileData[name] = {}
	vexalarm_SV_profileData[name]["data"] = vexalarm.initialize.checkTableData(vexalarm.defaults.general, vexalarm_SV_profileData[name]["data"], false)
	vexalarm_SV_profileData[name]["rw"] = vexalarm.initialize.checkTableData(vexalarm.defaults.rw, vexalarm_SV_profileData[name]["rw"], false)
	
	vexalarm_SV_profileData[name]["frames"] = {}
	vexalarm_SV_profileData[name]["frames"]["Mainframe"] = vexalarm.initialize.checkTableData(vexalarm.defaults.frame["Mainframe"], vexalarm_SV_profileData[name]["frames"]["Mainframe"], false)
	
	vexalarm_SV_profileData[name]["spellprofiles"] = {}
	vexalarm_SV_profileData[name]["spellprofiles"][name] = vexalarm.initialize.checkTableData(vexalarm.defaults.spells, vexalarm_SV_profileData[name]["spellprofiles"]["Default"], false)
end

function vexalarm.options.profiles.clone()
	local key = vexalarm.options.profiles.name
	if vexalarm.options.general.checkName(key) then
		if vexalarm_SV_profileData[vexalarm.options.profiles.current]~= nil then
			vexalarm_SV_profileData[key] = vexalarm.lib.copyTable(vexalarm_SV_profileData[vexalarm.options.profiles.current])
			
			vexalarm.options.profiles.name = ""
			
			vexalarm.options.profiles.feedback("save", "Profile saved successfully", false)
		else
			vexalarm.options.profiles.feedback("save", "Couldn't clone profile: profile to clone couldn't be found", true)
		end
	else
		vexalarm.options.profiles.feedback("save", "Couldn't save profil. Name is invalid.", true)
	end
end


function vexalarm.options.profiles.getList(default)
	local returnvalue = {}
	local timer = 0
	for key in pairs(vexalarm_SV_profileData) do
		if key == vexalarm_SV_defaultData["profile"] and default then
			returnvalue[key]=key.." (Default Profile)"
		else
			returnvalue[key]=key
		end
		timer = timer + 1
	end
	
	if timer == 0 then
		returnvalue[""] = "No saved profile found"
	end
	
	return returnvalue
end

function vexalarm.options.profiles.delete()
	local key = vexalarm.options.profiles.current
	
	if vexalarm.options.general.checkName(key) then
		vexalarm_SV_profileData[key] = nil
		vexalarm.options.profiles.name = ""
		vexalarm.options.profiles.current = ""
		
		vexalarm.options.profiles.feedback("delete", "Profile deleted successfully", false)
	else
		vexalarm.options.profiles.feedback("delete", "Couldn't delete profile. Profilename is not valid.", true)
	end
end

function vexalarm.options.profiles.rename()
	local key = vexalarm.options.profiles.current
	local name = vexalarm.options.profiles.name
	
	if vexalarm.options.general.checkName(name) and vexalarm_SV_profileData[key]~=nil then
		if key ~= name then
			vexalarm_SV_profileData[name] = vexalarm.lib.copyTable(vexalarm_SV_profileData[key])
			vexalarm_SV_profileData[key] = nil
			vexalarm.options.profiles.name = name
			vexalarm.options.profiles.current = name
			
			vexalarm.options.profiles.feedback("rename", "Profile renamed successfully", false)
		else
			vexalarm.options.profiles.feedback("rename", "Couldn't rename profile. Reason: The new name and the old name are the same.", true)
		end
	elseif not(vexalarm.options.general.checkName(name)) then
		vexalarm.options.profiles.feedback("rename", "Couldn't rename profile. New profilename is not valid.", true)
	elseif vexalarm_SV_profileData[key]==nil then
		vexalarm.options.profiles.feedback("rename", "Couldn't rename profile. Old profile wasn't found.", true)
	end
end

function vexalarm.options.profiles.load(fragment, noreload, all)
	local key = vexalarm.options.profiles.current
	if vexalarm.options.general.checkName(key) then
		if vexalarm_SV_profileData[key] ~= nil then 
			if fragment == "all" then
				vexalarm.options.profiles.load("frames", noreload, true)
				vexalarm.options.profiles.load("rw", noreload, true)
				vexalarm.options.profiles.load("spelldata", noreload, true)
			elseif fragment == "frames" then
				vexalarm_SV_profileData[vexalarm_SV_data["profile"]]["frames"] = vexalarm.lib.copyTable(vexalarm_SV_profileData[key]["frames"])
				vexalarm_SV_profileData[vexalarm_SV_data["profile"]]["data"] = vexalarm.lib.copyTable(vexalarm_SV_profileData[key]["data"])
			elseif fragment == "rw" then
				vexalarm_SV_profileData[vexalarm_SV_data["profile"]]["rw"] = vexalarm.lib.copyTable(vexalarm_SV_profileData[key]["rw"])
			elseif fragment == "spelldata" then
				for k,v in pairs (vexalarm.lib.copyTable(vexalarm_SV_profileData[key]["spellprofiles"])) do
					vexalarm_SV_profileData[vexalarm_SV_data["profile"]]["spellprofiles"][k] = vexalarm.lib.copyTable(v)
				end
			end
			if not(noreload) then
				vexalarm.initialize.core(true)
			end
		end
		
		local load_string = ""
		if fragment == "all" then
			load_string = "Complete profile"
		elseif not(all) and fragment == "spelldata" then
			load_string = "Spelldata"
		elseif not(all) and fragment == "rw" then
			load_string = "Raid-Warnings"
		elseif not(all) and fragment == "frames" then
			load_string = "Frames"
		end
		vexalarm.options.profiles.feedback("load", load_string.." loaded successfully", false)
	else
		vexalarm.options.profiles.feedback("load", "Couldn't load profile. Profile name is invalid.", true)
	end
end